powered by
List the available template by name that can be used with draft() to create a new document for R Markdown from a package.
draft()
available_templates(package = "rmarkdown", full_path = FALSE)
Package to list template from. Default to rmarkdown
Set to TRUE to get the full path to the available templates
TRUE
A character vector of templates name to use within draft(). If full_path = TRUE, it returns the full path to the templates.
full_path = TRUE
# NOT RUN { # List rmarkdown templates & create a draft available_templates() # List rticles templates available_templates("rticles") # }
Run the code above in your browser using DataLab